@@ -10,9 +10,9 @@
 */
 
 #include "mainwindow.h"
-#include "config-kontact.h"
 using namespace Qt::Literals::StringLiterals;
 
+#include "config-kontact.h"
 #include "iconsidepane.h"
 #include "kontactconfiguredialog.h"
 #include "prefs.h"
@@ -74,6 +74,7 @@ using namespace Kontact;
 
 #include <PimCommon/NeedUpdateVersionUtils>
 #include <PimCommon/NeedUpdateVersionWidget>
+#include <PimCommon/VerifyNewVersionWidget>
 
 // signal handler for SIGINT & SIGTERM
 #ifdef Q_OS_UNIX
@@ -84,6 +85,9 @@ using namespace Kontact;
 
 MainWindow::MainWindow()
     : KontactInterface::Core()
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    , mVerifyNewVersionWidget(new PimCommon::VerifyNewVersionWidget(this))
+#endif
 {
 #ifdef Q_OS_UNIX
     /**
@@ -352,6 +356,17 @@ void MainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
+
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#if KONTACT_STABLE_VERSION
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/kontact/25.04/windows/");
+#else
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/kontact/master/windows/");
+#endif
+    mVerifyNewVersionWidget->addOsUrlInfo(PimCommon::VerifyNewVersionWidget::OsVersion::Windows, url);
+    auto verifyNewVersionAction = mVerifyNewVersionWidget->verifyNewVersionAction();
+    actionCollection()->addAction(QStringLiteral("verify_check_version"), verifyNewVersionAction);
+#endif
 }
 
 void MainWindow::slotToggleMenubar(bool dontShowWarning)
